Segment class

Annotations
  • @JsonSerializable.new()

Constructors

Segment({int? position, int? id, Gallery? gallery, File? file, String? target, String? html, String? action})
Segment.fromJson(Map<String, dynamic> json)
factory

Properties

action String?
getter/setter pair
file File?
getter/setter pair
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
html String?
getter/setter pair
id int?
getter/setter pair
position int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited