ThemeConfigurationField class

Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

ThemeConfigurationField({String? name, String? type, Map<String, String>? label})
ThemeConfigurationField.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
label Map<String, String>?
getter/setter pair
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited