ThemeConfigurationStructure class
- Annotations
-
- @JsonSerializable.new(createToJson: false)
Constructors
-
ThemeConfigurationStructure({Map<
String, String> ? title, Iterable<ThemeConfigurationGroup> ? groups, ThemeConfigurationLinks? links}) -
ThemeConfigurationStructure.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
groups
↔ Iterable<
ThemeConfigurationGroup> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- links ↔ ThemeConfigurationLinks?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
title
↔ Map<
String, String> ? -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited