ThemeConfigurationLinks class
- Annotations
-
- @JsonSerializable.new(createToJson: false)
Constructors
-
ThemeConfigurationLinks({Map<String, Map<String, String>>? segmentPages, Map<String, Map<String, String>>? pages, Map<String, Map<String, String>>? forms, Map<String, Map<String, String>>? galleries, Map<String, Map<String, String>>? files, Map<String, Map<String, String>>? blogCategories})
-
-
ThemeConfigurationLinks.fromJson(Map<String, dynamic> json)
-
factory
Properties
-
blogCategories
↔ Map<String, Map<String, String>>?
-
getter/setter pair
-
files
↔ Map<String, Map<String, String>>?
-
getter/setter pair
-
forms
↔ Map<String, Map<String, String>>?
-
getter/setter pair
-
galleries
↔ Map<String, Map<String, String>>?
-
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
getter/setter pair
-
pages
↔ Map<String, Map<String, String>>?
-
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
segmentPages
↔ Map<String, Map<String, String>>?
-
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited